ProvidedConstructor Type
Represents an erased provided constructor.
Constructors
| Constructor |
Description
|
Full Usage:
ProvidedConstructor(parameters, invokeCode)
Parameters:
ProvidedParameter list
invokeCode : Expr list -> Expr
Returns: ProvidedConstructor
|
When making a cross-targeting type provider, use this method instead of the ProvidedConstructor constructor from ProvidedTypes
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AddDefinitionLocation
Parameters:
int
column : int
filePath : string
|
Add definition location information to the provided constructor.
|
Full Usage:
this.AddObsoleteAttribute
Parameters:
string
?isError : bool
|
Add a 'Obsolete' attribute to this provided constructor
|
Full Usage:
this.AddXmlDoc
Parameters:
string
|
Add XML documentation information to this provided constructor
|
Full Usage:
this.AddXmlDocComputed
Parameters:
unit -> string
|
Add XML documentation information to this provided constructor, where the documentation is re-computed every time it is required.
|
Full Usage:
this.AddXmlDocDelayed
Parameters:
unit -> string
|
Add XML documentation information to this provided constructor, where the computation of the documentation is delayed until necessary
|
Full Usage:
this.BaseConstructorCall
|
Set the target and arguments of the base constructor call. Only used for generated types. |
Full Usage:
this.IsImplicitConstructor
|
Set a flag indicating that the constructor acts like an F# implicit constructor, so the parameters of the constructor become fields and can be accessed using Expr.GlobalVar with the same name. |
Full Usage:
this.IsTypeInitializer
|
|
FSharp.TypeProviders.SDK