ProvidedEvent Type
Represents an erased provided property.
Constructors
| Constructor |
Description
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AddDefinitionLocation
Parameters:
int
column : int
filePath : string
|
Add definition location information to the provided type definition.
|
Full Usage:
this.AddXmlDoc
Parameters:
string
|
Add XML documentation information to this provided constructor
|
Full Usage:
this.AddXmlDocComputed
Parameters:
unit -> string
|
Add XML documentation information to this provided constructor, where the computation of the documentation is delayed until necessary The documentation is re-computed every time it is required.
|
Full Usage:
this.AddXmlDocDelayed
Parameters:
unit -> string
|
Add XML documentation information to this provided constructor, where the computation of the documentation is delayed until necessary
|
Full Usage:
this.IsStatic
Returns: bool
|
Get a flag indicating if the property is static.
|
FSharp.TypeProviders.SDK