ProvidedField Type
Represents an erased provided field.
Constructors
| Constructor |
Description
|
Full Usage:
ProvidedField(fieldName, fieldType)
Parameters:
string
fieldType : Type
Returns: ProvidedField
|
Create a new provided field. It is not initially associated with any specific provided type definition.
|
Instance members
| Instance member |
Description
|
|
Add a custom attribute to the provided property definition.
|
Full Usage:
this.AddDefinitionLocation
Parameters:
int
column : int
filePath : string
|
Add definition location information to the provided field definition.
|
Full Usage:
this.AddObsoleteAttribute
Parameters:
string
?isError : bool
|
Add a 'Obsolete' attribute to this provided field
|
Full Usage:
this.AddXmlDoc
Parameters:
string
|
Add XML documentation information to this provided field
|
Full Usage:
this.AddXmlDocComputed
Parameters:
unit -> string
|
Add XML documentation information to this provided field, where the computation of the documentation is delayed until necessary The documentation is re-computed every time it is required.
|
Full Usage:
this.AddXmlDocDelayed
Parameters:
unit -> string
|
Add XML documentation information to this provided field, where the computation of the documentation is delayed until necessary
|
|
|
Static members
| Static member |
Description
|
Full Usage:
ProvidedField.Literal(fieldName, fieldType, literalValue)
Parameters:
string
fieldType : Type
literalValue : obj
Returns: ProvidedField
|
Create a new provided literal field. It is not initially associated with any specific provided type definition.
|
FSharp.TypeProviders.SDK