obj
Helps create erased provided unit-of-measure annotations.
ProvidedMeasureBuilder.AnnotateType(basic, argument)
Type
Type list
Returns a type where the type has been annotated with the given types and/or units-of-measure. e.g. float, Vector
ProvidedMeasureBuilder.Inverse(denominator)
Returns the measure indicating the inverse of two units of measure, e.g. 1 / s
ProvidedMeasureBuilder.One
Gets the measure indicating the "1" unit of measure, that is the unitless measure.
ProvidedMeasureBuilder.Product(measure1, measure2)
Returns the measure indicating the product of two units of measure, e.g. kg * m
ProvidedMeasureBuilder.Ratio(numerator, denominator)
Returns the measure indicating the ratio of two units of measure, e.g. kg / m
ProvidedMeasureBuilder.SI(unitName)
string
Returns the measure for an SI unit from the F# core library, where the string is in capitals and US spelling, e.g. Meter
ProvidedMeasureBuilder.Square(measure)
Returns the measure indicating the square of a unit of measure, e.g. m * m
Type something to start searching.