ProvidedStaticParameter Type
Represents a provided static parameter.
Constructors
| Constructor |
Description
|
Full Usage:
ProvidedStaticParameter(parameterName, parameterType, ?parameterDefaultValue)
Parameters:
string
parameterType : Type
?parameterDefaultValue : obj
Returns: ProvidedStaticParameter
|
Create a new provided static parameter, for use with DefineStaticParameters on a provided type definition.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AddXmlDoc
Parameters:
string
|
Add XML documentation information to this provided constructor
|
Full Usage:
this.AddXmlDocDelayed
Parameters:
unit -> string
|
Add XML documentation information to this provided constructor, where the computation of the documentation is delayed until necessary
|
FSharp.TypeProviders.SDK