ProvidedTypesContext Type
Instance members
| Instance member |
Description
|
|
Add an assembly to the set of design-time assemblies available to use as a basis for authoring provided types
|
|
|
|
|
|
|
|
Try to get the version of FSharp.Core referenced. May raise an exception if FSharp.Core has not been correctly resolved
|
|
Get the set of design-time assemblies available to use as a basis for authoring provided types.
|
|
Get the resolved referenced assemblies determined by the type provider configuration
|
|
|
|
|
Full Usage:
this.TryBindAssemblyNameToTarget
Parameters:
AssemblyName
Returns: Choice<Assembly, exn>
|
Try to find the given target assembly in the context
|
|
FSharp.TypeProviders.SDK