ProvidedTypeSymbol Type
Represents an array or other symbolic type involving a provided type as the argument. See the type provider spec for the methods that must be implemented. Note that the type provider specification does not require us to implement pointer-equality for provided types.
Instance members
| Instance member |
Description
|
Full Usage:
this.IsFSharpTypeAbbreviation
Returns: bool
|
For example, kg
|
Full Usage:
this.IsFSharpUnitAnnotated
Returns: bool
|
For example, int
|
FSharp.TypeProviders.SDK